package gs

import sbt._

object CalVerPlugin extends AutoPlugin {
  override def trigger = allRequirements

  val autoImport = CalVerKeys

  import autoImport._

  lazy val calVerDefaults: Seq[Setting[_]] =
    Seq(
      calVerReleasePattern    := Some(CalVer.Defaults.ReleasePattern),
      calVerPreReleasePattern := Some(CalVer.Defaults.PreReleasePattern)
    )

  override lazy val projectSettings: Seq[Setting[_]] = {
    val isRelease = PluginProperties.isRelease()

    Seq(
      calVerPattern := {
        if (isRelease)
          calVerReleasePattern.value.getOrElse(CalVer.Defaults.ReleasePattern)
        else
          calVerPreReleasePattern.value.getOrElse(
            CalVer.Defaults.PreReleasePattern
          )
      },
      calVer := CalVer.render(calVerPattern.value).value,
      calVerInfo := {
        val log = Keys.streams.value.log
        log.info(s"[CalVer] Version: ${calVer.value}")
        log.info(s"[CalVer] Pattern: ${calVerPattern.value}")
      }
    )
  }

  // Automatically exposed globally.
  override lazy val globalSettings: Seq[Setting[_]] = calVerDefaults
}
